@@ -26,8 +26,9 @@ import com.operationaldynamics.driver.DefsFile;
 public class SetterBlock extends AccessorBlock
 {
     SetterBlock(final BoxedBlock parent, final String gType, final String name) {
+        // TODO mmm, how can we know if a field can be null?
         super(name, parent, Collections.singletonList(new String[] {
-                gType, name
+                gType, name, "no"
         }));
 
         this.returnType = gType;
